%define module  demjson

Name:           python-%{module}
Version:        2.2.4
Release:        %mkrel 1
Summary:        Python JSON module and lint checker
Group:          Development/Python
License:        LGPLv3+
URL:            http://deron.meranda.us/python/demjson/
Source0:        http://deron.meranda.us/python/demjson/dist/%{module}-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  pkgconfig(python2)
BuildRequires:  pythonegg(2)(setuptools)
# needed for 2to3
BuildRequires:  pythonegg(2)(pytools)

Provides:       jsonlint
Provides:       pythonegg(2)(jsonlint)

%description
This module provides classes and functions for encoding or decoding
data represented in the language-neutral JSON format (which is often
used as a simpler substitute for XML in Ajax web applications).  This
implementation tries to be as compliant to the JSON specification (RFC
4627) as possible, while still providing many optional extensions to
allow less restrictive JavaScript syntax.  It includes complete
Unicode support, including UTF-32, BOM, and surrogate pair processing.
It can also support JavaScript's NaN and Infinity numeric types as
well as it's 'undefined' type.

It also includes a lint-like JSON syntax validator which tests JSON
text for strict compliance to the standard.

#------------------------------------------------------------------

%package -n     python3-%{module}
Summary:        Python 3 JSON module and lint checker
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
BuildRequires:  pythonegg(3)(setuptools)

Provides:       python3-jsonlint
Provides:       pythonegg(3)(jsonlint)

%description -n python3-%{module}
This module provides classes and functions for encoding or decoding
data represented in the language-neutral JSON format (which is often
used as a simpler substitute for XML in Ajax web applications).  This
implementation tries to be as compliant to the JSON specification (RFC
4627) as possible, while still providing many optional extensions to
allow less restrictive JavaScript syntax.  It includes complete
Unicode support, including UTF-32, BOM, and surrogate pair processing.
It can also support JavaScript's NaN and Infinity numeric types as
well as it's 'undefined' type.

It also includes a lint-like JSON syntax validator which tests JSON
text for strict compliance to the standard.

#------------------------------------------------------------------
%prep
%setup -q -n %{module}-%{version}

#for python3 build
cp -a . %{py3dir}

%build
%py2_build

pushd %{py3dir}
%py3_build
popd

%install
pushd %{py3dir}
%py3_install
# rename binary
mv %{buildroot}%{_bindir}/jsonlint %{buildroot}%{_bindir}/python3-jsonlint
# fix shebang lines
find %{buildroot}%{python3_sitelib} -name '*.py' -exec \
     sed -i "1{/^#!/d}" {} \;
popd

%py2_install
# fix shebang lines
find %{buildroot}%{python2_sitelib} -name '*.py' -exec \
     sed -i "1{/^#!/d}" {} \;

%check
%define enable_tests_python2 1
%if %{enable_tests_python2}
cd test
PYTHONPATH=%{buildroot}%{python2_sitelib} \
%{__python2} test_demjson.py
%endif
%define enable_tests_python3 1
%if %{enable_tests_python3}
pushd %{py3dir}
cd test
2to3 -w --no-diffs test_demjson.py
PYTHONPATH=%{buildroot}%{python3_sitelib} \
%{__python3} test_demjson.py
popd
%endif

%files
%doc README.txt README.md LICENSE.txt docs
%doc docs
%{python2_sitelib}/*
%{_bindir}/jsonlint

%files -n python3-%{module}
%doc README.txt README.md LICENSE.txt docs
%doc docs
%{python3_sitelib}/*
%{_bindir}/python3-jsonlint


%changelog
* Wed Dec 23 2015 daviddavid <daviddavid> 2.2.4-1.mga6
+ Revision: 913885
- new version: 2.2.4
- BR pythonegg(2)(pytools) needed for 2to3
- improve %%check section for tests

* Wed Oct 07 2015 daviddavid <daviddavid> 2.2.3-2.mga6
+ Revision: 886789
- rebuild for python 3.5
- use new python macros

* Sun Jun 21 2015 daviddavid <daviddavid> 2.2.3-1.mga6
+ Revision: 837985
- new version: 2.2.3
- add more docs

* Wed Oct 15 2014 umeabot <umeabot> 2.2.2-4.mga5
+ Revision: 744236
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.2.2-3.mga5
+ Revision: 728228
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.2.2-2.mga5
+ Revision: 687963
- Mageia 5 Mass Rebuild

* Fri Aug 22 2014 daviddavid <daviddavid> 2.2.2-1.mga5
+ Revision: 666560
- enable tests on %%check section
- provide python3 subpackage
- modernize spec file
- new version: 2.2.2

  + pterjan <pterjan>
    - Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1.6-4.mga4
+ Revision: 543101
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.6-3.mga4
+ Revision: 498358
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Jan 13 2013 umeabot <umeabot> 1.6-2.mga3
+ Revision: 378659
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 09 2012 matteo <matteo> 1.6-1.mga3
+ Revision: 291103
- fixed buildrequirement python-setuptools
- spec file reviewed
- Import Fedora package


* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Apr  4 2011 Thomas Moschny <thomas.moschny@gmx.de> - 1.6-1
- Update to 1.6.
- Injecting setuptools is only needed for EPEL5.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Oct 27 2010 Thomas Moschny <thomas.moschny@gmx.de> - 1.5-1
- Update to 1.5.
- Remove patch no longer needed.

* Wed Oct 27 2010 Thomas Moschny <thomas.moschny@gmx.de> - 1.4-1
- Update to 1.4. Upstream changed license to LGPLv3+.
- Apply a one-liner patch provided upstream.

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 1.3-6
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 1.3-3
- Rebuild for Python 2.6

* Mon Mar 31 2008 Thomas Moschny <thomas.moschny@gmx.de> - 1.3-2
- Cleanup BuildRequires.
- Don't pack INSTALL.txt.

* Thu Mar 27 2008 Thomas Moschny <thomas.moschny@gmx.de> - 1.3-1
- New package.
